@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-debug.c,v 1.10 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-debug.c,v 1.11 2006/01/19 18:16:00 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -66,8 +66,8 @@ gedit_debug_init ()
 		debug = debug | GEDIT_DEBUG_PRINT;
 	if (g_getenv ("GEDIT_DEBUG_PLUGINS") != NULL)
 		debug = debug | GEDIT_DEBUG_PLUGINS;
-	if (g_getenv ("GEDIT_DEBUG_FILE") != NULL)
-		debug = debug | GEDIT_DEBUG_FILE;
+	if (g_getenv ("GEDIT_DEBUG_TAB") != NULL)
+		debug = debug | GEDIT_DEBUG_TAB;
 	if (g_getenv ("GEDIT_DEBUG_DOCUMENT") != NULL)
 		debug = debug | GEDIT_DEBUG_DOCUMENT;
 	if (g_getenv ("GEDIT_DEBUG_COMMANDS") != NULL)
